Option Explicit

'********************************************************************************************************************************************
' Script Name: DPCerts_Upgrade.vbs
'
' Purpose:  Purpose of this srcipt is to locate cacerts files on the client side found under the lib/security folder under the default
'   location(s) where Java is installed by a user and generate a bacth file called DPCerts_Upgrade.bat and a log file for the VBS script run.
'  Note DPCerts_Upgrade.vbs does not perform the update, it generates the DPCerts_Upgrade.bat file which when run will perform the update.
'
' Pre Conditions:  The script must be located in the folder C:\NYDEX_CLIENT\DataPowerCerts_2015_09_02_Update
'
' Post Conditions: The script will generate the following files in the C:\NYDEX_CLIENT\DataPowerCerts_2015_09_02_Update folder
'  DPCerts_Upgrade.bat - A batch file that will perform the actual cacerts.
'    The batch file will only update cacerts files for Java versions located under the following folders:"
'      C:\Program Files\Java".
'      C:\Program Files (x86)\Java".
'
'    The batch file will backup the existing cacerts file to a file called cacerts_nydex_09_02_2015_updated_on%BatchRunTimeExt% in the same folder.
'    The %BatchRunTimeExt% is a place holder that will be translated into the time when the batch file actually runs.
'    If the backup file can be created from the current cacerts file is replaced by the updated cacerts_DPCerts_Upgrade_Master found in 
'      the C:\NYDEX_CLIENT\DataPowerCerts_2015_09_02_Update folder.
'    If the backup file cannot be created then nothing will get updated.
'
'    ******* NOTE the batch file must be run with admin rights. ******
'    ******* NOTE the batch file must be run to perform the actual update. ******
'    When run the bacth will attempt to perform the update and will generate a batch log file of its results called 
'      DPCerts_Upgrade_Batch{time when the bacth file is run}.log.  This file can be checked to verify the cacerts files were update.
'
'  DPCerts_Upgrade_On_{time when DPCerts_Upgrade.vbs was run}
'    This is a file that generates a log of the activities performed by DPCerts_Upgrade.vbs.
'********************************************************************************************************************************************

' setup objects
dim objFSO
dim objLogFile
dim objBatchFile
dim objFolder
dim objSubFolder
dim colSubFolders

' setup variables
' run time and run time parts
dim whenRun
dim year_part
dim day_part
dim month_part
dim hour_part
dim minute_part
dim second_part

' log file variables
dim logFileFolder
dim logFileBase
dim logFileWhen
dim logFileExt
dim logFile

' backup file variables
dim backupFileBase
dim backupFile

' batch file variables
dim batchFile
dim batchFileContents
dim batchFileLog
dim batchFileLogBase
dim batchFileLogExt

' master update file
dim masterUpdateFile

' file search variables
dim startFolder
dim colFiles

Function Lpad(strInput, length, character)
  Lpad = Right(String(length, character) & strInput, length)
end function

Sub GetSubFolders (folder)
  For Each objSubFolder in folder.SubFolders
    if (objSubFolder.name = "security") then
      if objFSO.FileExists(objSubFolder.path & "\cacerts") then
        ' update the batch file
        batchFileContents = batchFileContents & "echo **** >> " & batchFileLog & vbCrLf
        batchFileContents = batchFileContents & "echo **************************************************************************************************************************************************** >> " & batchFileLog & vbCrLf
        batchFileContents =  batchFileContents & "rem Actions for folder " & objSubFolder.path & vbCrLf
        batchFileContents =  batchFileContents & "move " & chr(34) & objSubFolder.path & "\cacerts" & chr(34) & " " & chr(34) & objSubFolder.path & "\" & backupFile & chr(34) & vbCrLf
        batchFileContents =  batchFileContents & "if exist " & chr(34) & objSubFolder.path & "\" & backupFile & chr(34) & " (" & vbCrLf
        batchFileContents =  batchFileContents & "   copy " & chr(34) & masterUpdateFile & chr(34) & " " & chr(34) & objSubFolder.path & "\cacerts" & chr(34) & vbCrLf
        batchFileContents =  batchFileContents & "   echo " & objSubFolder.path & "\cacerts backed up to " & objSubFolder.path & "\" & backupFile & " >> " & batchFileLog & vbCrLf
        batchFileContents =  batchFileContents & "   echo " & objSubFolder.path & "\cacerts updated with " & masterUpdateFile & " >> " & batchFileLog & vbCrLf
        batchFileContents =  batchFileContents & ") else (" & vbCrLf
        batchFileContents =  batchFileContents &  "    echo Could not create the backup file " & objSubFolder.path & "\" & backupFile & " >> " & batchFileLog & vbCrLf
        batchFileContents =  batchFileContents &  "    echo " & objSubFolder.path & "\cacerts could not be updated" & " >> " & batchFileLog & vbCrLf
        batchFileContents =  batchFileContents & ")" & vbCrLf & vbCrLf
        ' update the log file
        objLogFile.WriteLine "Folder: " & objSubFolder.path
        objLogFile.WriteLine "  The generated batch file will backup the cacerts file to " & objSubFolder.path & "\" & backupFile
        objLogFile.WriteLine "  and will update the " & objSubFolder.path & "\cacerts file." 
        objLogFile.WriteLine 
      end if
    end if 
    GetSubFolders (objSubFolder)
  Next
End Sub

Set objFSO = CreateObject("Scripting.FileSystemObject")

' Get when this script is run
whenRun     = now

' Break the whenRun into parts to be used for the file name
year_part   = DatePart("yyyy",whenRun)
month_part  = DatePart("m",whenRun)
day_part    = DatePart("d",whenRun)
hour_part   = DatePart("h",whenRun)
minute_part = DatePart("n",whenRun)
second_part = DatePart("s",whenRun)

' The file name for the script log will be the base + the run time + .log
logFileFolder = "C:\NYDEX_CLIENT\DataPowerCerts_2015_09_02_Update\"
logFileBase = "DPCerts_Upgrade_On_"
logFileWhen = year_part & "_" & Lpad(month_part, 2, "0") & "_" & Lpad(day_part, 2, "0") & "_" & Lpad(hour_part, 2, "0") & "_" & Lpad(minute_part, 2, "0") & "_" & Lpad(second_part, 2, "0")
logFileExt  = ".log"
logFile = logFileFolder & logFileBase & logFileWhen & logFileExt

' The name of the backup file created. 
backupFileBase = "cacerts_nydex_09_02_2015_updated_on"
' %BackupRunTime% is a batch file varialbe built at batch file run time
backupFile     = backupFileBase & "%BatchRunTimeExt%" 

' The name of the batch file
batchFile        = logFileFolder & "DPCerts_Upgrade.bat"
batchFileLogBase = "DPCerts_Upgrade_Batch"
batchFileLogExt  = ".log"
' TargetFile is the name of the batchFileLog build at batch run time
batchFileLog     = "%TargetLogFile%"

' The name of the master update file
masterUpdateFile = logFileFolder & "cacerts_DPCerts_Upgrade_Master" 

Set objLogFile   = objFSO.OpenTextFile(logFile,2,TRUE)
Set objBatchFile = objFSO.OpenTextFile(batchFile,2,TRUE)

batchFileContents =  "rem This batch file was created by the DPCerts_Upgrade.vbs on " & whenRun & vbCrLf & vbCrLf


batchFileContents = batchFileContents & "rem The purpose of this batch file is to update certificates on the client side for the DCJS DataPower servers for the 9/2/2015 server updates." & vbCrLf & vbCrLf
batchFileContents = batchFileContents & "rem These certificates on the client side for Java will be located in the cacerts file found under the lib/security" & vbCrLf
batchFileContents = batchFileContents & "rem  folder under the default location(s) where Java is installed by a user." & vbCrLf & vbCrLf

batchFileContents = batchFileContents & "rem The batch file will only update cacerts files for Java versions located under the following folders:" & vbCrLf
batchFileContents = batchFileContents & "rem   C:\Program Files\Java" & vbCrLf
batchFileContents = batchFileContents & "rem   C:\Program Files (x86)\Java" & vbCrLf & vbCrLf

'Write out the target directory in the batch file
batchFileContents = batchFileContents & "SET TargetDir=" & logFileFolder & vbCrLf & vbCrLf

'Build varialbes for the time when the batch file is run
batchFileContents = batchFileContents & "Rem the next two for loops get the date and time in a format to use to create a extended file name based on the run time of the batch file" & vbCrLf
batchFileContents = batchFileContents & "for /f " & chr(34) & "tokens=1-4 delims=/- "  & chr(34) & " %%a in ('date /t') do set XDate=%%b_%%c_%%d"& vbCrLf & vbCrLf
batchFileContents = batchFileContents & "for /f " & chr(34) & "tokens=1-3 delims=: "  & chr(34) & " %%a in ('time /t') do set XTime=%%a_%%b_%%c" & vbCrLf & vbCrLf

' Set batch run time extension
batchFileContents = batchFileContents & "SET BatchRunTimeExt=_%XDate%_%XTime%" & vbCrLf & vbCrLf

'Build the log file name in the batch file
batchFileContents = batchFileContents & "REM set the TargetFile based on the date and time" & vbCrLf
batchFileContents = batchFileContents & "SET TargetLogFile=%TargetDir%" & batchFileLogBase & "%BatchRunTimeExt%" & batchFileLogExt & vbCrLf & vbCrLf

'Write out batch file log created on messages
batchFileContents = batchFileContents & "rem This batch fill will create a batch file log called " & logFileFolder & batchFileLogBase & "{time the batch file ran}"  & batchFileLogExt  & " with the time of the batch file ran as part of the file name." & vbCrLf 
batchFileContents = batchFileContents & "rem The log contains the action performed by the batch file." & vbCrLf
batchFileContents = batchFileContents & "echo This log file was generated by the batch file " & batchFile & " on %XDate% at %XTime% > " & batchFileLog & vbCrLf & vbCrLf


'Write out the batch log information to the VBS script log
objLogFile.WriteLine "This log was created by the DPCerts_Upgrade.vbs on " & whenRun
objLogFile.WriteLine
objLogFile.WriteLine "The purpose of this script is to update certificates on the client side for the DCJS DataPower servers for the 9/2/2015 server updates."
objLogFile.WriteLine
objLogFile.WriteLine "These certificates on the client side for Java will be located in the cacerts file found under the lib/security"
objLogFile.WriteLine " folder under the default location(s) where Java is installed by a user."
objLogFile.WriteLine
objLogFile.WriteLine "The batch file will only update cacerts files for Java versions located under the following folders:"
objLogFile.WriteLine "  C:\Program Files\Java"
objLogFile.WriteLine "  C:\Program Files (x86)\Java"
objLogFile.WriteLine
objLogFile.WriteLine "The locations shown below will reference a batch variable called %BatchRunTimeExt% which will be translated in the time when the batch file actually runs."
objLogFile.WriteLine "At the time this script log file was generated, the batch file has not yet run so the %BatchRunTimeExt% is a pace holder for the actual run time value."
objLogFile.WriteLine

startFolder = "C:\Program Files\Java"
objLogFile.WriteLine "Processing folders under " & startFolder & " for cacerts file."
objLogFile.WriteLine "*******************************************************************************"
objLogFile.WriteLine
If objFSO.FolderExists(startFolder) then
  set objFolder = objFSO.GetFolder(startFolder)
  GetSubFolders (objFolder)
Else
  objLogFile.WriteLine "The folder " & startFolder & " does not exist on this computer."
  objLogFile.WriteLine "*******************************************************************************"
  objLogFile.WriteLine
End if

startFolder = "C:\Program Files (x86)\Java"
objLogFile.WriteLine "Processing folders under " & startFolder & " for cacerts file."
objLogFile.WriteLine "*******************************************************************************"
objLogFile.WriteLine
If objFSO.FolderExists(startFolder) then
  set objFolder = objFSO.GetFolder(startFolder)
  GetSubFolders (objFolder)
Else
  objLogFile.WriteLine "The folder " & startFolder & " does not exist on this computer."
  objLogFile.WriteLine "*******************************************************************************"
  objLogFile.WriteLine
End if

objBatchFile.Write BatchFileContents

objLogFile.WriteLine
objLogFile.WriteLine
objLogFile.WriteLine "*************************************************************************************"
objLogFile.WriteLine "The batch file called " & batchFile & " was created with the contents below:"
objLogFile.WriteLine "*************************************************************************************"
objLogFile.WriteLine
objLogFile.Write BatchFileContents
 
objLogFile.close
objBatchFile.close